package de.hhu.ba.yoshikoWrapper.core;

import java.util.Collection;
import java.util.HashMap;
import java.util.Locale;
import java.util.ResourceBundle;

/** Static collection of functions and states representing the current locale and providing access to localized strings
 *  This class should never be initialized
 */
public class LocalizationManager {
	
	/**
	 * Default constructor, hidden to prevent invocation
	 */
	private LocalizationManager() {};
	
	//Locales
	
	static private final Locale usEnglish = new Locale("en","US");
	static private final Locale german = new Locale("de","DE");
	//Map
	
    static private final HashMap<String, Locale> locales;
    static
    {
        locales = new HashMap<String, Locale>();
        locales.put("enUS", usEnglish);
        locales.put("deDE", german);
    }

	
	static private ResourceBundle currentBundle;
	
	static private Locale currentLocale = usEnglish;

	
	private static void updateBundle() {
		currentBundle = ResourceBundle.getBundle("YoshikoStrings",currentLocale);
		CyCore.cm.getProperties().setProperty(
				"locale",
				currentLocale.getLanguage()+currentLocale.getCountry()
				);
	}
	

	//SETTER/GETTER methods
	
	static public Collection<Locale> getLocales(){
		return locales.values();
	}
	
	/**
	 * Returns the localized string corresponding to the given key.
	 * This is the main method that should be used for accessing strings and is preferable to any use of constant strings.
	 * @param key The key for the string (refer to YoshikoStrings.properties for all possible keys)
	 * @return The localized string
	 */
	static public String get(String key) {
		if (currentBundle == null) {
			currentBundle = ResourceBundle.getBundle("YoshikoStrings",currentLocale);
		}
		return currentBundle.getString(key);
	}
	
	static public void switchLanguage(Locale lcl) {
		currentLocale = lcl;
		updateBundle();
	}

	public static void switchLanguage(String key) {
		System.out.println("DEBUG: SWITCHING TO: "+key);
		currentLocale = locales.get(key);
		updateBundle();
	}

	public static Locale getCurrentLocale() {
		return currentLocale;
	}
}
