package de.hhu.ba.yoshikoWrapper.gui;


import java.awt.FlowLayout;

import javax.swing.BoxLayout;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;

import org.cytoscape.model.CyColumn;
import org.cytoscape.model.CyNetwork;

import de.hhu.ba.yoshikoWrapper.core.CyCore;

@SuppressWarnings("serial") //will never be serialized
public class ColumnMapper extends ComfortPanel{
	

	//Swing components
	private final JComboBox<CyColumn> editingCostMapper;
	private final JComboBox<CyColumn> permanentMapper;
	private final JComboBox<CyColumn> forbiddenMapper;
		
	private final JCheckBox useMappingCost;
	private final JCheckBox useMappingPerm;
	private final JCheckBox useMappingForb;
	
	private final ComfortPanel costGroup;
	private final ComfortPanel permGroup;
	private final ComfortPanel forbGroup;
		
	public ColumnMapper() {
		this.setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));

		//SWING COMPONENTS
		
		//Combo-Boxes that map to the CyColumns
		editingCostMapper = new JComboBox<CyColumn>();
		permanentMapper = new JComboBox<CyColumn>();
		forbiddenMapper = new JComboBox<CyColumn>();
		
		//Should only be enabled if the option is checked
		editingCostMapper.setEnabled(false);
		permanentMapper.setEnabled(false);
		forbiddenMapper.setEnabled(false);

		useMappingCost = new JCheckBox("Map modification costs");
		useMappingPerm = new JCheckBox("Map edges as permanent");
		useMappingForb = new JCheckBox("Map edges as forbidden");
		
		useMappingCost.addActionListener(
			new EnableWhenSelectedListener(useMappingCost, editingCostMapper)
		);
		useMappingPerm.addActionListener(
			new EnableWhenSelectedListener(useMappingPerm, permanentMapper)
			);
		useMappingForb.addActionListener(
			new EnableWhenSelectedListener(useMappingForb, forbiddenMapper)
		);
		
		costGroup = new ComfortPanel();
		permGroup = new ComfortPanel();
		forbGroup = new ComfortPanel();
		
		costGroup.setLayout(new FlowLayout());
		permGroup.setLayout(new FlowLayout());
		forbGroup.setLayout(new FlowLayout());

		costGroup.addAll(useMappingCost,editingCostMapper);
		permGroup.addAll(useMappingPerm,permanentMapper);
		forbGroup.addAll(useMappingForb,forbiddenMapper);

		
		this.addAll(costGroup,permGroup,forbGroup);
		
		//Initial call to get table values
		updateValues();

	}
	
	public void updateValues() {
		
		CyNetwork net = CyCore.cy.getCurrentNetwork();

		if (net != null) { //Check if a network is loaded
	
			//Clear entries
			editingCostMapper.removeAllItems();
			for (CyColumn c : net.getDefaultEdgeTable().getColumns()){
				//Only add columns with numeric values
				if (c.getType() == Integer.class || c.getType() == Double.class) {
					editingCostMapper.addItem(c);
				}
			}
			
			forbiddenMapper.removeAllItems();
			for (CyColumn c : net.getDefaultEdgeTable().getColumns()){
				//Only add columns with boolean values
				if (c.getType() == Boolean.class) {
					forbiddenMapper.addItem(c);
				}
			}
			
			permanentMapper.removeAllItems();
			for (CyColumn c : net.getDefaultEdgeTable().getColumns()){
				//Only add columns with boolean values
				if (c.getType() == Boolean.class) {
					permanentMapper.addItem(c);
				}
			}
		
		}
	}
	
	public CyColumn getEditingCostColumn() {
		if (useMappingCost.isSelected()) {
			return editingCostMapper.getItemAt(editingCostMapper.getSelectedIndex());
		}
		return null;
	}
	
	public CyColumn getForbiddenColumn() {
		if (useMappingForb.isSelected()) {
			return forbiddenMapper.getItemAt(forbiddenMapper.getSelectedIndex());
		}
		return null;
	}
	
	public CyColumn getPermanentColumn() {
		if (useMappingPerm.isSelected()) {
			return permanentMapper.getItemAt(permanentMapper.getSelectedIndex());
		}
		return null;
	}

}
