package de.hhu.ba.yoshikoWrapper.gui;

import java.awt.FlowLayout;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.border.Border;
import javax.swing.border.EtchedBorder;

import org.cytoscape.model.CyColumn;

import de.hhu.ba.yoshikoWrapper.core.LocalizationManager;

@SuppressWarnings("serial") //Will never be serialized
public class EditCostPanel extends ComfortPanel {
	
	//SWING COMPONENTS
	private ColumnMapper columnMapper;
	
	private DoubleInputField  icField;
	private DoubleInputField dcField;
	
	private JLabel icLabel;
	private JLabel dcLabel;
	
	private ComfortPanel groupIC;
	private ComfortPanel groupDC;
	
	public EditCostPanel() {
		//Define Layout
		this.setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));
		//Initialize components
		columnMapper = new ColumnMapper();
		
		icField = new DoubleInputField(Double.NEGATIVE_INFINITY,0);
		dcField = new DoubleInputField(0,Double.POSITIVE_INFINITY);
		
		icField.setText("-1.0");
		icField.setToolTipText(LocalizationManager.get("icTooltip"));
		dcField.setText("1.0");
		
		icLabel = new JLabel(LocalizationManager.get("defaultInsertion"));
		dcLabel = new JLabel(LocalizationManager.get("defaultDeletion"));
		//Group the labels with their text fields
		groupIC = new ComfortPanel();
		groupDC = new ComfortPanel();
		
		groupIC.setLayout(new FlowLayout());
		groupDC.setLayout(new FlowLayout());

		groupIC.addAll(icLabel,icField);
		groupDC.addAll(dcLabel,dcField);
		
		this.addAll(columnMapper,groupIC,groupDC);
		
		//Decoration/Visual
		Border border = BorderFactory.createEtchedBorder(EtchedBorder.LOWERED);
		border = BorderFactory.createTitledBorder(border,LocalizationManager.get("editingCostPanel"));

		this.setBorder(border);
	}
	
	//SETTER / GETTER

	public CyColumn getWeightColumn() {
		return columnMapper.getEditingCostColumn();
	}
	
	public CyColumn getPermanentColumn() {
		return columnMapper.getPermanentColumn();
	}
	
	public CyColumn getForbiddenColumn() {
		return columnMapper.getForbiddenColumn();
	}

	public double getDefaultInsertionCost() {
		return icField.getValueAsDouble();
	}
	
	public double getDefaultDeletionCost() {
		return dcField.getValueAsDouble();
	}

	public ColumnMapper getColumnMapper() {
		return columnMapper;
	}


	
}
