package de.hhu.ba.yoshikoWrapper.gui;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JCheckBox;
import javax.swing.JRadioButton;
import javax.swing.border.Border;
import javax.swing.border.EtchedBorder;

import de.hhu.ba.yoshikoWrapper.core.LocalizationManager;

@SuppressWarnings("serial")
public class OperationModePanel extends ComfortPanel{
	private final JRadioButton useHeuristic;
	private final JRadioButton useILP;
	private final TimeLimitSetter timeLimitSetter;
	private final SolutionNumberChooser solutionNumberChooser;
	private final JCheckBox useTriangleCutsBox;
	private final JCheckBox usePartitionCutsBox;
	
	private final ButtonGroup heuristicGroup;

	public OperationModePanel() {
		
		this.setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));
		
		heuristicGroup = new ButtonGroup();
		useILP = new JRadioButton("Use Integer Linear Programming");
		useILP.setSelected(true);

		useHeuristic = new JRadioButton("Use Heuristic");
		heuristicGroup.add(useILP);
		heuristicGroup.add(useHeuristic);
		
		solutionNumberChooser = new SolutionNumberChooser();
		

		timeLimitSetter = new TimeLimitSetter();
				
		useTriangleCutsBox = new JCheckBox("Use Triangle Cuts");
		usePartitionCutsBox = new JCheckBox("Use Partition Cuts");
		
		//Link time limit option to ILP
		useILP.addActionListener(ilpHeuristicSwitch);
		useHeuristic.addActionListener(ilpHeuristicSwitch);
		

		this.addAll(useILP,useHeuristic,solutionNumberChooser,timeLimitSetter,useTriangleCutsBox,usePartitionCutsBox);
		
		Border border = BorderFactory.createEtchedBorder(EtchedBorder.LOWERED);
		border = BorderFactory.createTitledBorder(border,LocalizationManager.get("operationMode"));
		this.setBorder(border);
	}
	
	ActionListener ilpHeuristicSwitch = new ActionListener() {
		@Override
		public void actionPerformed(ActionEvent e) {
			if (useILP.isSelected()) {
				timeLimitSetter.setEnabled(true);
				useTriangleCutsBox.setEnabled(true);
				usePartitionCutsBox.setEnabled(true);
				solutionNumberChooser.setEnabled(true);
			}
			else {
				timeLimitSetter.setEnabled(false);
				useTriangleCutsBox.setEnabled(false);
				usePartitionCutsBox.setEnabled(false);
				solutionNumberChooser.setEnabled(false);
			}
		}	
	};
	
	//SETTER GETTER

	public int getTimeLimit() {
		return timeLimitSetter.getTimeLimit();
	}

	public boolean useTriangleCuts() {
		return useTriangleCutsBox.isSelected();
	}

	public boolean usePartitionCuts() {
		return usePartitionCutsBox.isSelected();
	}

	public boolean useHeuristic() {
		return useHeuristic.isSelected();
	}

	public int getSolCount() {
		return solutionNumberChooser.getSolCount();
	}
}
