package de.hhu.ba.yoshikoWrapper.gui;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BoxLayout;
import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JTabbedPane;

import org.cytoscape.application.swing.CytoPanelComponent;
import org.cytoscape.application.swing.CytoPanelName;

import de.hhu.ba.yoshikoWrapper.core.CyCore;
import de.hhu.ba.yoshikoWrapper.core.LocalizationManager;
import de.hhu.ba.yoshikoWrapper.graphModel.YoshikoResult;
import de.hhu.ba.yoshikoWrapper.graphModel.YoshikoSolution;

/**Swing component that contains ALL solutions that are found during one run.
 * Conforms to CY 3.5 by being a CytoPanelComponent which is the norm for "result" panels
 */
@SuppressWarnings("serial")//Will never be serialized
public class ResultPanel extends ComfortPanel implements CytoPanelComponent{
	
	private final JTabbedPane solutionTabs;
	private final JLabel costLabel;
	private final JButton destroyButton;
	
	private final YoshikoResult result;
		
	public ResultPanel(YoshikoResult result) {
				
		this.result = result;
		
		setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));
		
		//Init subcomponents
		solutionTabs = new JTabbedPane();
		for (YoshikoSolution s : result.solutions) {
			addSolutionTab(s);
		}

		costLabel = new JLabel();
		setCost(result.editingCost);
		
		destroyButton = new JButton(LocalizationManager.get("discardSolution"));
		destroyButton.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				deleteSolution();
			}
			
		});
		
		addAll(costLabel,solutionTabs,destroyButton);
	}
	
	public void deleteSolution() {
		int dialogResult = JOptionPane.showConfirmDialog (
				null,
				LocalizationManager.get("deleteSolution"),
				LocalizationManager.get("warning"),
				JOptionPane.YES_NO_OPTION
		);
		if (dialogResult != JOptionPane.YES_OPTION) {
			return;
		}
		
		CyCore.registrar.unregisterService(this,CytoPanelComponent.class);
		removeAll();
		super.setVisible(false);
	}
	
	private void addSolutionTab(YoshikoSolution s) {
		SolutionTab tab = new SolutionTab(s);
		solutionTabs.add(
				LocalizationManager.get("solution")+" "+(s.id+1),
				tab
		);
	}

	public void setCost(double modificationCost) {
		costLabel.setText(LocalizationManager.get("cost")+" "+modificationCost);
		revalidate();
		repaint();
	}

	@Override
	public Component getComponent() {
		return this;
	}

	@Override
	public CytoPanelName getCytoPanelName() {
		return CytoPanelName.EAST;
	}

	@Override
	public String getTitle() {
		return LocalizationManager.get("resultsPanelTitle");
	}

	@Override
	public Icon getIcon() {
		// TODO Auto-generated method stub
		return null;
	}

}
